<!-- footer -->
    <div class="container ">
  <div class="row">
    <div class="col-md-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="height: 60px ;position: relative;width:100%">
          <!-- place horizontal line -->
     <!--      <span style="width:10000px;height: 1px;background: #dddddd;position: absolute;display: inline-block;left: 50%;margin-left: -190px;top: 0px;margin-top: 30px;" ></span> -->
        <span style="width:100%;height: 1px;background: #dddddd;position: absolute;display: inline-block;top: 0px;margin-top: 30px;" ></span>
        </div>
    </div>
    </div>
  </div>

  <div class="container ">
  <div class="row">
    <div class="col-md-9 col-12 " style="padding-left: 0px!important;padding-right: 0px!important;" > 
        <div style="width: 16%;text-align: center;display: inline-block;vertical-align:top;text-align: left;" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">疫苗<p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">香港疫苗概览</p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">香港疫苗计划</p>
          </div>
          <div style="display: block;margin-top: 18px;">
             <p style="color: #989898;margin-bottom: 0rem;">香港疫苗流程</p>
          </div>
           <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">香港疫苗常见问题</p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">内地疫苗概览</p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">内地疫苗计划</p>
          </div>
          <div style="display: block;margin-top: 18px;">
             <p style="color: #989898;margin-bottom: 0rem;">内地疫苗流程</p>
          </div>
           <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">内地疫苗常见问题</p>
          </div>
        </div>
        <div style="width: 16%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">医疗<p>
          </div>
         <!--  <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div>
          <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">疫苗服務</p>
          </div> -->
          
        </div>
        <div style="width: 16%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">儿科知识<p>
          </div>
       <!--    <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div> -->
          
        </div>
        <div style="width: 16%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">医疗团队<p>
          </div>
   <!--        <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div> -->
          
        </div>
        <div style="width: 16%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">诊所环境<p>
          </div>
   <!--        <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div> -->
          
        </div>
         <div style="width: 16%;text-align: center;display: inline-block;vertical-align:top" >
          <div style="display: block;" >
            <p style="color: #a64a55;margin-bottom: 0rem;">查询预约<p>
          </div>
   <!--        <div style="display: block;margin-top: 18px;">
            <p style="color: #989898;margin-bottom: 0rem;">服務內容</p>
          </div> -->
          
        </div>
    </div>
    <div class="col-md-3 col-12 " style="padding-left: 10px!important;padding-right: 0px!important;" >

      <table>
        <tr>
          <td width="90%">  <p style="color: #a64a55;margin-bottom: 0rem;">新世纪香港医疗中心</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">地址：香港九龙尖沙咀海港城海洋中心1328-29 室</p> </td>
          
          <td rowspan="5"></td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">电话：+852 2886 0066</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">电邮：
info@ncich.com.hk</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">WhatsApp: 6706 5853</p> </td>
        </tr>
        <tr>
          <td>
             <img src="../img/qrcode1.png" width="90px" height="90px">
          </td>
        </tr>
        <!--  <tr>
          <td width="90%" >  <br><p style="color: #a64a55;margin-bottom: 0rem;">新世紀兒童發展中心</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">地址：香港九龍尖沙咀海港城海洋中心1330室</p> </td>
          
          <td rowspan="5"> <img src="../img/qrcode2.png" width="90px" height="90px"></td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">電話：+852 2886 2382</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">WhatsApp: 6858 2565</p> </td>
        </tr>
        <tr>
          <td>  <p style="color: #989898;margin-bottom: 0rem;">WeChat: NEWCENTURY_CDC_TST</p> </td>
        </tr> -->
      </table>  
     
     <!--    <div style="width: 100%;display: block;" class="redbr">
         <p style="color: #a64a55;margin-bottom: 0rem;">新世紀香港醫療中心</p> 
          <div style="display: inline-block;float: left;">
            <p style="color: #989898;margin-bottom: 0rem;">地圵:</p>
            <p style="color: #989898;margin-bottom: 0rem;">電話:</p>
            <p style="color: #989898;margin-bottom: 0rem;">電郵:</p>
            <p style="color: #989898;margin-bottom: 0rem;">WhatApp:</p>
          </div>
          <div style="display: inline-block;float: right;">
              <img src="../img/qrcode1.png" width="90px" height="90px">
          </div>

         </div> -->
    </div>
 </div>
</div>
<div class="row" style="height: 70px;background-color: #a64a55;text-align: center;">
  <div style="height: 100%;vertical-align: center;width: 100%;text-align: center;"  >
  <p style="width: 100%;color: white;margin-top: 20px;">@2005-2019 新世纪香港医疗中心</p>
  <!-- <p style="width: 100%;color: white;margin-top: 30px;">©2005-2019 新世紀香港醫療中心</p> -->
  </div>
</div>
  <!-- end footer -->


  <!-- </footer> -->